#!/bin/sh
IMAGE="$1"
JSON_SCAN="$2"

EXIT_NA=0
EXIT_OPERATIONAL=1  # i.e. unknown
EXIT_FIPS_NONCAPABLE=2
#EXIT_FIPS_CAPABLE=3
EXIT_FIPS_ENFORCED=4
SHELL=/bin/sh
DOCKER_HOST_DIR=$(docker inspect "$(hostname)" | jq -r '.[] | .GraphDriver | .Data | .MergedDir') # We need this because we are already 1 level deep

if ! docker run --rm --entrypoint "${SHELL}" "${IMAGE}" -c "true"
then
	echo "Could not run ${SHELL} in ${IMAGE}"
	# TODO: implement check for distroless containers (from scratch)
	exit "${EXIT_OPERATIONAL}"
fi


PYTHON_FOUND=0
# Loop through all python interpreters
# Note: jq was compiled without ONIGURUMA regex libary. match/test/sub and related functions are not available.
PYTHON_FROM_JSON=$(jq  -r '.results[0] | .applications | .[] | .path' "${JSON_SCAN}" | grep '/python[^/]*$')
PYTHON_FROM_PATH=$(docker run --rm --entrypoint /bin/sh "${IMAGE}" -c 'find $(echo $PATH | sed "s:\:: :g") -name "python*" 2>/dev/null')
PYTHON_PATHS=$(echo "${PYTHON_FROM_JSON}" "${PYTHON_FROM_PATH}" | sort -u)
for path in ${PYTHON_PATHS}
do
	# Check if this is python3 interpreter
	OUTPUT=$(docker run --rm --entrypoint "${SHELL}" "${IMAGE}" -c "${path} -c 'import sys; sys.version[0] == \"3\" or sys.exit(1); print(\"printed\")'")
	if test "${OUTPUT}" = "printed"
	then
		echo "Python3 interpreter found"
		PYTHON_FOUND=1

		docker run --rm --entrypoint "${SHELL}" -v "${DOCKER_HOST_DIR}/${PWD}/additional:/check" "${IMAGE}" -i -c "${path} /check/check_fips.py"
		EXIT_CODE=$?
		if test ${EXIT_CODE} -eq 0
		then
			echo "${path} is in FIPS mode"
		else
			# This python interpreter is NOT in FIPS mode
			echo "${path} is not in FIPS mode"
			exit "${EXIT_FIPS_NONCAPABLE}"
		fi
	fi
done

if test ${PYTHON_FOUND} -eq 1
then
	# All python interpreters are in FIPS mode
	exit "${EXIT_FIPS_ENFORCED}"
fi

# No python interpreters found
exit "${EXIT_NA}"
